==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/FUNCTION_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FUNCTION_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FUNCTION_Type">
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}EXTMENU_Type">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMFUNCTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TAB" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FUNCTION_Type", propOrder = {
    "functionid",
    "systemfunction",
    "systempermissions",
    "usergrouppermissions",
    "tab"
})
public class FUNCTION_Type
    extends EXTMENU_Type
{

    @XmlElement(name = "FUNCTIONID", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "SYSTEMFUNCTION", required = true)
    protected String systemfunction;
    @XmlElement(name = "SYSTEMPERMISSIONS")
    protected PERMISSIONS_Type systempermissions;
    @XmlElement(name = "USERGROUPPERMISSIONS")
    protected PERMISSIONS_Type usergrouppermissions;
    @XmlElement(name = "TAB")
    protected List<TAB_Type> tab;

    /**
     * Obtient la valeur de la propriété functionid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Définit la valeur de la propriété functionid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Obtient la valeur de la propriété systemfunction.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSYSTEMFUNCTION() {
        return systemfunction;
    }

    /**
     * Définit la valeur de la propriété systemfunction.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSYSTEMFUNCTION(String value) {
        this.systemfunction = value;
    }

    /**
     * Obtient la valeur de la propriété systempermissions.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getSYSTEMPERMISSIONS() {
        return systempermissions;
    }

    /**
     * Définit la valeur de la propriété systempermissions.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setSYSTEMPERMISSIONS(PERMISSIONS_Type value) {
        this.systempermissions = value;
    }

    /**
     * Obtient la valeur de la propriété usergrouppermissions.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getUSERGROUPPERMISSIONS() {
        return usergrouppermissions;
    }

    /**
     * Définit la valeur de la propriété usergrouppermissions.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setUSERGROUPPERMISSIONS(PERMISSIONS_Type value) {
        this.usergrouppermissions = value;
    }

    /**
     * Gets the value of the tab property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tab property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTAB().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TAB_Type }
     * 
     * 
     */
    public List<TAB_Type> getTAB() {
        if (tab == null) {
            tab = new ArrayList<TAB_Type>();
        }
        return this.tab;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/FUNCTION_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FUNCTION_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FUNCTION_Type">
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}EXTMENU_Type">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMFUNCTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TAB" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FUNCTION_Type", propOrder = {
    "functionid",
    "systemfunction",
    "systempermissions",
    "usergrouppermissions",
    "tab"
})
public class FUNCTION_Type
    extends EXTMENU_Type
{

    @XmlElement(name = "FUNCTIONID", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "SYSTEMFUNCTION", required = true)
    protected String systemfunction;
    @XmlElement(name = "SYSTEMPERMISSIONS")
    protected PERMISSIONS_Type systempermissions;
    @XmlElement(name = "USERGROUPPERMISSIONS")
    protected PERMISSIONS_Type usergrouppermissions;
    @XmlElement(name = "TAB")
    protected List<TAB_Type> tab;

    /**
     * Gets the value of the functionid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Sets the value of the functionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Gets the value of the systemfunction property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSYSTEMFUNCTION() {
        return systemfunction;
    }

    /**
     * Sets the value of the systemfunction property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSYSTEMFUNCTION(String value) {
        this.systemfunction = value;
    }

    /**
     * Gets the value of the systempermissions property.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getSYSTEMPERMISSIONS() {
        return systempermissions;
    }

    /**
     * Sets the value of the systempermissions property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setSYSTEMPERMISSIONS(PERMISSIONS_Type value) {
        this.systempermissions = value;
    }

    /**
     * Gets the value of the usergrouppermissions property.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getUSERGROUPPERMISSIONS() {
        return usergrouppermissions;
    }

    /**
     * Sets the value of the usergrouppermissions property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setUSERGROUPPERMISSIONS(PERMISSIONS_Type value) {
        this.usergrouppermissions = value;
    }

    /**
     * Gets the value of the tab property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tab property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTAB().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TAB_Type }
     * 
     * 
     */
    public List<TAB_Type> getTAB() {
        if (tab == null) {
            tab = new ArrayList<TAB_Type>();
        }
        return this.tab;
    }

}
